@@ -22,16 +22,21 @@
 '''
 '''
 
-__version__ = "1.2.2"
+__version__ = "1.2.3"
 
 __all__ = [
   'cnclient',
+  'cnclient_1_1',
   'd1baseclient',
+  'd1baseclient_1_1',
   'd1client',
+  'data_package',
   'logrecorditerator',
   'mnclient',
+  'mnclient_1_1',
+  'object_format_info',
   'objectlistiterator',
-  'solrclient',
+  'solr_client',
   'svnrevision',
   'systemmetadata',
 ]
